https://git.reactos.org/?p=reactos.git;a=commitdiff;h=00ffe2dfff1269a0ba233…
commit 00ffe2dfff1269a0ba2331bf3e6104e68c9e4d32
Author: Chris Spiegel <cspiegel(a)gmail.com>
AuthorDate: Tue Dec 21 04:40:54 2021 -0800
Commit: GitHub <noreply(a)github.com>
CommitDate: Tue Dec 21 13:40:54 2021 +0100
[NETSHELL] Improve workgroup vs. domain wording (#4172)
---
dll/shellext/netshell/lang/bg-BG.rc | 2 +-
dll/shellext/netshell/lang/da-DK.rc | 2 +-
dll/shellext/netshell/lang/el-GR.rc | 2 +-
dll/shellext/netshell/lang/en-US.rc | 2 +-
dll/shellext/netshell/lang/he-IL.rc | 2 +-
dll/shellext/netshell/lang/id-ID.rc | 2 +-
dll/shellext/netshell/lang/it-IT.rc | 2 +-
dll/shellext/netshell/lang/nl-NL.rc | 2 +-
dll/shellext/netshell/lang/no-NO.rc | 2 +-
dll/shellext/netshell/lang/sk-SK.rc | 2 +-
dll/shellext/netshell/lang/sq-AL.rc | 2 +-
dll/shellext/netshell/lang/sv-SE.rc | 2 +-
12 files changed, 12 insertions(+), 12 deletions(-)
diff --git a/dll/shellext/netshell/lang/bg-BG.rc b/dll/shellext/netshell/lang/bg-BG.rc
index f04138264c6..002b525a593 100644
--- a/dll/shellext/netshell/lang/bg-BG.rc
+++ b/dll/shellext/netshell/lang/bg-BG.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/da-DK.rc b/dll/shellext/netshell/lang/da-DK.rc
index 61ca49a6dde..26b8287135d 100644
--- a/dll/shellext/netshell/lang/da-DK.rc
+++ b/dll/shellext/netshell/lang/da-DK.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/el-GR.rc b/dll/shellext/netshell/lang/el-GR.rc
index 0a4c91ecfdd..4c15fa7aa96 100644
--- a/dll/shellext/netshell/lang/el-GR.rc
+++ b/dll/shellext/netshell/lang/el-GR.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/en-US.rc b/dll/shellext/netshell/lang/en-US.rc
index 2e2ce20f62d..b4ee99d6133 100644
--- a/dll/shellext/netshell/lang/en-US.rc
+++ b/dll/shellext/netshell/lang/en-US.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/he-IL.rc b/dll/shellext/netshell/lang/he-IL.rc
index 66b574ec56f..ec9c451b8bf 100644
--- a/dll/shellext/netshell/lang/he-IL.rc
+++ b/dll/shellext/netshell/lang/he-IL.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/id-ID.rc b/dll/shellext/netshell/lang/id-ID.rc
index 433a47b2395..c86de12e25f 100644
--- a/dll/shellext/netshell/lang/id-ID.rc
+++ b/dll/shellext/netshell/lang/id-ID.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/it-IT.rc b/dll/shellext/netshell/lang/it-IT.rc
index dad2dce9f42..5dcebcc84bb 100644
--- a/dll/shellext/netshell/lang/it-IT.rc
+++ b/dll/shellext/netshell/lang/it-IT.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/nl-NL.rc b/dll/shellext/netshell/lang/nl-NL.rc
index 25ee11f62b2..1176299d32f 100644
--- a/dll/shellext/netshell/lang/nl-NL.rc
+++ b/dll/shellext/netshell/lang/nl-NL.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/no-NO.rc b/dll/shellext/netshell/lang/no-NO.rc
index 5ce8f378ff8..255576057d7 100644
--- a/dll/shellext/netshell/lang/no-NO.rc
+++ b/dll/shellext/netshell/lang/no-NO.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/sk-SK.rc b/dll/shellext/netshell/lang/sk-SK.rc
index 7a85afa35bc..0185831ed76 100644
--- a/dll/shellext/netshell/lang/sk-SK.rc
+++ b/dll/shellext/netshell/lang/sk-SK.rc
@@ -116,7 +116,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/sq-AL.rc b/dll/shellext/netshell/lang/sq-AL.rc
index 63fdda10dc4..26173d9d35a 100644
--- a/dll/shellext/netshell/lang/sq-AL.rc
+++ b/dll/shellext/netshell/lang/sq-AL.rc
@@ -115,7 +115,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
diff --git a/dll/shellext/netshell/lang/sv-SE.rc b/dll/shellext/netshell/lang/sv-SE.rc
index 15d9ebd16b5..a01d9ca335c 100644
--- a/dll/shellext/netshell/lang/sv-SE.rc
+++ b/dll/shellext/netshell/lang/sv-SE.rc
@@ -111,7 +111,7 @@ FONT 8, "MS Shell Dlg"
BEGIN
LTEXT "Do you want this computer to be a member of a domain?\n\
(You can obtain this information from your network administrator.)", IDC_STATIC, 33, 2, 263, 50
- AUTORADIOBUTTON "No, this computer will be part of a workgroup.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
+ AUTORADIOBUTTON "No, this computer will be part of a workgroup instead.", IDC_SELECT_WORKGROUP, 33, 32, 253, 20, WS_TABSTOP | WS_GROUP
AUTORADIOBUTTON "Yes, this computer will be part of a domain.", IDC_SELECT_DOMAIN, 33, 47, 253, 20, WS_TABSTOP
LTEXT "Workgroup or Domain Name:", IDC_STATIC, 33, 72, 126, 14
EDITTEXT IDC_DOMAIN_NAME, 33, 82, 126, 14, WS_VISIBLE | WS_TABSTOP | ES_AUTOHSCROLL
https://git.reactos.org/?p=reactos.git;a=commitdiff;h=8a6312abda24d11d6c9ab…
commit 8a6312abda24d11d6c9abfe133013b32e4aef3e6
Author: Oleg Dubinskiy <oleg.dubinskij2013(a)yandex.ua>
AuthorDate: Mon Dec 20 20:27:13 2021 +0000
Commit: GitHub <noreply(a)github.com>
CommitDate: Mon Dec 20 21:27:13 2021 +0100
[WIN32SS][NTDDRAW] Improve DxEngGetDCState type 2 implementation (#4176)
- Use the REGION_Complexity() function to get the actual region complexity instead of just number of rectangles.
- Don't use prgnRao at all, because it is always uninitialized when passed to the function. So in condition between prgnRao and prgnVis, the 2nd one always succeeds.
- Update the comment accordingly.
- Additionally, add a DPRINT to the end of the function, which displays the returned value.
This allows to properly enable and use DirectDraw and Direct3D hardware acceleration with the following MS DirectX components: ddraw.dll, d3d8.dll, d3d9.dll and dxg.sys. As in VM, same on real hardware.
But note that now the bugcheck 0x50 (PAGE_FAULT_IN_NONPAGED_AREA) occurs when executing fullscreen DDraw apps, after switching display mode. It's unhidden by this fix.
Addendum to 855bf46.
CORE-17561
---
win32ss/reactx/ntddraw/dxeng.c | 6 ++++--
1 file changed, 4 insertions(+), 2 deletions(-)
diff --git a/win32ss/reactx/ntddraw/dxeng.c b/win32ss/reactx/ntddraw/dxeng.c
index 24cb542643e..7004e58e480 100644
--- a/win32ss/reactx/ntddraw/dxeng.c
+++ b/win32ss/reactx/ntddraw/dxeng.c
@@ -464,8 +464,8 @@ DxEngGetDCState(HDC hDC,
retVal = (DWORD_PTR) pDC->fs & DC_FLAG_FULLSCREEN;
break;
case 2:
- /* Return the number of rectangles in the visible region. */
- retVal = (DWORD_PTR) pDC->prgnRao ? pDC->prgnRao->rdh.nCount : pDC->prgnVis->rdh.nCount;
+ /* Return the complexity of the visible region. */
+ retVal = (DWORD_PTR) REGION_Complexity(pDC->prgnVis);
break;
case 3:
{
@@ -481,6 +481,8 @@ DxEngGetDCState(HDC hDC,
DC_UnlockDc(pDC);
}
+ DPRINT1("Return value %08lx\n", retVal);
+
return retVal;
}